@@ -58,7 +58,7 @@ class KeyedProcedure(Procedure):
 
     def validate(self):
         for action in self.actions:
-            if not action.name:
+            if action.name is None:
                 msg = f'All {self.__class__.__name__} Actions must have a name: {str(action)}'
                 raise KeyedProcedure.UnnamedAction(msg)
 
